pub struct FbmCoordinateParameters {
pub mul_x: f32,
pub mul_y: f32,
pub add_x: f32,
pub add_y: f32,
}Expand description
Represents the coordinates used in the *_fbm methods.
Fields
mul_x: f32See the *_fbm methods for details on how this parameter is used.
mul_y: f32See the *_fbm methods for details on how this parameter is used.
add_x: f32See the *_fbm methods for details on how this parameter is used.
add_y: f32See the *_fbm methods for details on how this parameter is used.