Color

Struct Color 

pub struct Color {
    pub r: u8,
    pub g: u8,
    pub b: u8,
    pub a: u8,
}
A struct representing a 24-bit RGB color with alpha

Fields

r: u8

The red component of the color

g: u8

The green component of the color

b: u8

The blue component of the color

a: u8

The opacity of the color

Implementations

Source

impl Color

pub const fn new(r: u8, g: u8, b: u8) -> Self

Returns a new Color from RGB values.

Parameters
  • r - The color’s amount of red.
  • g - The color’s amount of green.
  • b - The color’s amount of blue.
Example
let white = Color::new(255, 255, 255);
pub const fn new_with_alpha(r: u8, g: u8, b: u8, a: u8) -> Self

Returns a new Color from RGB values with an opacity.

Parameters
  • r - The color’s amount of red.
  • g - The color’s amount of green.
  • b - The color’s amount of blue.
  • a - The color’s opacity.
Example
let translucent_white = Color::new_with_alpha(255, 255, 255, 127);
pub fn new_hsv(hue: f32, saturation: f32, value: f32) -> Self

Returns a new Color from HSV values.

The saturation and value parameters are automatically clamped to 0 and 1.

Use set_hsv() to fill an existing struct with HSV values.

Parameters
  • hue - The color’s hue in degrees.
  • saturation - The color’s saturation, from 0 to 1.
  • value - The color’s value, from 0 to 1.
Example
let light_blue = Color::new_hsv(240.0, 0.75, 1.0);
pub fn new_hsv_with_opacity( hue: f32, saturation: f32, value: f32, opacity: f32, ) -> Self

Returns a new Color from HSV values with the given opacity.

The saturation, value and opacity parameters are automatically clamped to 0 and 1.

Use set_hsv() to fill an existing struct with HSV values.

Parameters
  • hue - The color’s hue in degrees.
  • saturation - The color’s saturation, from 0 to 1.
  • value - The color’s value, from 0 to 1.
  • opacity - The color’s opacity, from 0 to 1.
Example
let translucent_light_blue = Color::new_hsv_with_opacity(240.0, 0.75, 1.0, 0.5);
pub fn set_hsv(&mut self, hue: f32, saturation: f32, value: f32)

Sets a colors values from HSV values.

Parameters
  • hue - The color’s hue in degrees.
  • saturation - The color’s saturation, from 0 to 1.
  • value - The color’s value, from 0 to 1.

Values outside the given ranges are clipped to fit within the allowed range.

pub fn get_hsv(self) -> (f32, f32, f32)

Get a tuple of HSV values from a color.

pub fn set_hue(&mut self, hue: f32)

Change a color’s hue.

Parameters
  • hue - The color’s hue in degrees. Values outside the given range loop around to fit within the allowed range.
Examples
// Sets the hue of the color to 16 degrees.
color.set_hue(16.);
// Values outside the range of 0-360 will be clipped:
color.set_hue(420.);

// The hue is actually set to 60 degrees.
let hue = color.get_hue();
assert!((hue - 60.).abs() < 1.);

color.set_hue(-90.);

// The hue is actually set to 270 degrees.
let hue = color.get_hue();
assert!((hue - 270.).abs() < 1.);
pub fn get_hue(self) -> f32

Return a color’s hue in degrees. See set_hue for examples.

pub fn get_saturation(self) -> f32

Returns a color’s saturation in the range [0, 1]. See set_saturation for examples.

pub fn set_saturation(&mut self, saturation: f32)

Change a color’s saturation.

Parameters
  • saturation - The color’s saturation, from 0 to 1. Values outside the given range are clipped to fit within the allowed range.
Examples
// Sets the saturation of the color to 0.75.
color.set_saturation(0.75);
// Values outside the range of 0-1 will be clipped:
color.set_saturation(2.);

// The saturation is actually set to 1.
let saturation = color.get_saturation();
assert!((saturation - 1.).abs() < 0.001);

color.set_saturation(-2.);

// The saturation is actually set to 1.
let saturation = color.get_saturation();
assert!((saturation - 0.).abs() < 0.001);
pub fn get_value(self) -> f32

Returns a color’s value in the range [0, 1].

pub fn set_value(&mut self, value: f32)

Change a color’s value.

Parameters
  • value - The color’s value, from 0 to 1.
Examples
// Sets the value of the color to 0.25.
color.set_value(0.25);
// Values outside the range of 0-1 will be clipped:
color.set_value(2.);

// The saturation is actually set to 1.
let value = color.get_value();
assert!((value - 1.).abs() < 0.001);

color.set_value(-2.);

// The saturation is actually set to 0.
let value = color.get_value();
assert!((value - 0.).abs() < 0.001);
pub fn shift_hue(&mut self, hue_shift: f32)

Shift a color’s hue by an amount.

Parameters
  • hue_shift - The distance to shift the hue, in degrees.
Example
// Shift the hue by 10 degrees
color.shift_hue(10.);

// Shift the hue back to what it was originally
color.shift_hue(-10.);
pub fn scale_hsv(&mut self, saturation_coefficient: f32, value_coefficient: f32)

Scale a color’s saturation and value.

Parameters
  • saturation_coefficient - Multiplier for this color’s saturation.
  • value_coefficient - Multiplier for this color’s value.
Example

// Let's make a color with a saturation of 0.5 and a value of 0.75
let mut color = Color::new_hsv(10., 0.5, 0.75);

// Scale them by 1/2 and 1/3, respectively
color.scale_hsv(0.5, 1. / 3.);

// They should both be 0.25 now
assert!((color.get_saturation() - 0.25).abs() < 0.001);
assert!((color.get_value() - 0.25).abs() < 0.001);
pub fn generate_gradient_rgb( key_colors: &[Self], gradient_spans: &[usize], ) -> Vec<Self>

Generates an interpolated gradient of colors using RGB interpolation.

Using RGB interpolation between colors is almost always the wrong choice and tends to produce really ugly results. You almost certainly don’t want to use this; use generate_gradient_hsv() instead.

Parameters
  • key_colors - The colors to make gradients between.
  • gradient_spans - How many interpolated colors to generate between each pair of key colors.
Panics
  • If gradient_spans’ length isn’t one less than key_colors’ length.
Example
// Generates no colors at all
let none = Color::generate_gradient_rgb(&[], &[]);

assert!(none.is_empty());
// Generates only the given color
let one = Color::generate_gradient_rgb(&[Color::WHITE], &[]);

assert_eq!(one.len(), 1);
assert_eq!(one[0], Color::WHITE);
// Generates every grayscale color between black and white
let grayscale = Color::generate_gradient_rgb(&[Color::BLACK, Color::WHITE], &[254]);

assert_eq!(grayscale.len(), 256);
pub fn generate_gradient_hsv( key_colors: &[Self], gradient_spans: &[usize], ) -> Vec<Self>

Generates an interpolated gradient of colors using HSV interpolation.

Parameters
  • key_colors - The colors to make gradients between.
  • gradient_spans - How many interpolated colors to generate between each pair of key colors.
Panics
  • If gradient_spans’ length isn’t one less than key_colors’ length.
Examples
// Generates no colors at all
let none = Color::generate_gradient_hsv(&[], &[]);

assert!(none.is_empty());
// Generates only the given color
let one = Color::generate_gradient_hsv(&[Color::WHITE], &[]);

assert_eq!(one.len(), 1);
assert_eq!(one[0], Color::WHITE);
// Generates every grayscale color between black and white
let grayscale = Color::generate_gradient_hsv(&[Color::BLACK, Color::WHITE], &[254]);
pub fn lerp_rgb(self, other: Self, coefficient: f32) -> Self

Interpolate two colors together using their RGB representation and return the result.

You almost certainly don’t want to use this; use lerp_hsv() instead.

Parameters
  • other - The second color.
  • coefficient - The coefficient. 0 for entirely the first color, 1 for entirely the second.
Panics

If coefficient is outside the range [0, 1].

pub fn lerp_hsv(self, other: Self, coefficient: f32) -> Self

Interpolate two colors together using their HSV representation and return the result.

Parameters
  • other - The second color.
  • coefficient - The coefficient. 0 for entirely the first color, 1 for entirely the second.
Panics

If coefficient is outside the range [0, 1].

Source

impl Color

pub fn by_name_and_level(name: Name, level: Level) -> Self

Takes a Name and Level value and returns the corresponding color constant.

Source

impl Color

pub const BLACK: Self

pub const DARKEST_GRAY: Self

pub const DARKER_GRAY: Self

pub const DARK_GRAY: Self

pub const GRAY: Self

pub const LIGHT_GRAY: Self

pub const LIGHTER_GRAY: Self

pub const LIGHTEST_GRAY: Self

pub const DARKEST_GREY: Self = Self::DARKEST_GRAY

pub const DARKER_GREY: Self = Self::DARKER_GRAY

pub const DARK_GREY: Self = Self::DARK_GRAY

pub const GREY: Self = Self::GRAY

pub const LIGHT_GREY: Self = Self::LIGHT_GRAY

pub const LIGHTER_GREY: Self = Self::LIGHTER_GRAY

pub const LIGHTEST_GREY: Self = Self::LIGHTEST_GRAY

pub const WHITE: Self

pub const DARKEST_SEPIA: Self

pub const DARKER_SEPIA: Self

pub const DARK_SEPIA: Self

pub const SEPIA: Self

pub const LIGHT_SEPIA: Self

pub const LIGHTER_SEPIA: Self

pub const LIGHTEST_SEPIA: Self

pub const DESATURATED_RED: Self

pub const DESATURATED_FLAME: Self

pub const DESATURATED_ORANGE: Self

pub const DESATURATED_AMBER: Self

pub const DESATURATED_YELLOW: Self

pub const DESATURATED_LIME: Self

pub const DESATURATED_CHARTREUSE: Self

pub const DESATURATED_GREEN: Self

pub const DESATURATED_SEA: Self

pub const DESATURATED_TURQUOISE: Self

pub const DESATURATED_CYAN: Self

pub const DESATURATED_SKY: Self

pub const DESATURATED_AZURE: Self

pub const DESATURATED_BLUE: Self

pub const DESATURATED_HAN: Self

pub const DESATURATED_VIOLET: Self

pub const DESATURATED_PURPLE: Self

pub const DESATURATED_FUCHSIA: Self

pub const DESATURATED_MAGENTA: Self

pub const DESATURATED_PINK: Self

pub const DESATURATED_CRIMSON: Self

pub const LIGHTEST_RED: Self

pub const LIGHTEST_FLAME: Self

pub const LIGHTEST_ORANGE: Self

pub const LIGHTEST_AMBER: Self

pub const LIGHTEST_YELLOW: Self

pub const LIGHTEST_LIME: Self

pub const LIGHTEST_CHARTREUSE: Self

pub const LIGHTEST_GREEN: Self

pub const LIGHTEST_SEA: Self

pub const LIGHTEST_TURQUOISE: Self

pub const LIGHTEST_CYAN: Self

pub const LIGHTEST_SKY: Self

pub const LIGHTEST_AZURE: Self

pub const LIGHTEST_BLUE: Self

pub const LIGHTEST_HAN: Self

pub const LIGHTEST_VIOLET: Self

pub const LIGHTEST_PURPLE: Self

pub const LIGHTEST_FUCHSIA: Self

pub const LIGHTEST_MAGENTA: Self

pub const LIGHTEST_PINK: Self

pub const LIGHTEST_CRIMSON: Self

pub const LIGHTER_RED: Self

pub const LIGHTER_FLAME: Self

pub const LIGHTER_ORANGE: Self

pub const LIGHTER_AMBER: Self

pub const LIGHTER_YELLOW: Self

pub const LIGHTER_LIME: Self

pub const LIGHTER_CHARTREUSE: Self

pub const LIGHTER_GREEN: Self

pub const LIGHTER_SEA: Self

pub const LIGHTER_TURQUOISE: Self

pub const LIGHTER_CYAN: Self

pub const LIGHTER_SKY: Self

pub const LIGHTER_AZURE: Self

pub const LIGHTER_BLUE: Self

pub const LIGHTER_HAN: Self

pub const LIGHTER_VIOLET: Self

pub const LIGHTER_PURPLE: Self

pub const LIGHTER_FUCHSIA: Self

pub const LIGHTER_MAGENTA: Self

pub const LIGHTER_PINK: Self

pub const LIGHTER_CRIMSON: Self

pub const LIGHT_RED: Self

pub const LIGHT_FLAME: Self

pub const LIGHT_ORANGE: Self

pub const LIGHT_AMBER: Self

pub const LIGHT_YELLOW: Self

pub const LIGHT_LIME: Self

pub const LIGHT_CHARTREUSE: Self

pub const LIGHT_GREEN: Self

pub const LIGHT_SEA: Self

pub const LIGHT_TURQUOISE: Self

pub const LIGHT_CYAN: Self

pub const LIGHT_SKY: Self

pub const LIGHT_AZURE: Self

pub const LIGHT_BLUE: Self

pub const LIGHT_HAN: Self

pub const LIGHT_VIOLET: Self

pub const LIGHT_PURPLE: Self

pub const LIGHT_FUCHSIA: Self

pub const LIGHT_MAGENTA: Self

pub const LIGHT_PINK: Self

pub const LIGHT_CRIMSON: Self

pub const RED: Self

pub const FLAME: Self

pub const ORANGE: Self

pub const AMBER: Self

pub const YELLOW: Self

pub const LIME: Self

pub const CHARTREUSE: Self

pub const GREEN: Self

pub const SEA: Self

pub const TURQUOISE: Self

pub const CYAN: Self

pub const SKY: Self

pub const AZURE: Self

pub const BLUE: Self

pub const HAN: Self

pub const VIOLET: Self

pub const PURPLE: Self

pub const FUCHSIA: Self

pub const MAGENTA: Self

pub const PINK: Self

pub const CRIMSON: Self

pub const DARK_RED: Self

pub const DARK_FLAME: Self

pub const DARK_ORANGE: Self

pub const DARK_AMBER: Self

pub const DARK_YELLOW: Self

pub const DARK_LIME: Self

pub const DARK_CHARTREUSE: Self

pub const DARK_GREEN: Self

pub const DARK_SEA: Self

pub const DARK_TURQUOISE: Self

pub const DARK_CYAN: Self

pub const DARK_SKY: Self

pub const DARK_AZURE: Self

pub const DARK_BLUE: Self

pub const DARK_HAN: Self

pub const DARK_VIOLET: Self

pub const DARK_PURPLE: Self

pub const DARK_FUCHSIA: Self

pub const DARK_MAGENTA: Self

pub const DARK_PINK: Self

pub const DARK_CRIMSON: Self

pub const DARKER_RED: Self

pub const DARKER_FLAME: Self

pub const DARKER_ORANGE: Self

pub const DARKER_AMBER: Self

pub const DARKER_YELLOW: Self

pub const DARKER_LIME: Self

pub const DARKER_CHARTREUSE: Self

pub const DARKER_GREEN: Self

pub const DARKER_SEA: Self

pub const DARKER_TURQUOISE: Self

pub const DARKER_CYAN: Self

pub const DARKER_SKY: Self

pub const DARKER_AZURE: Self

pub const DARKER_BLUE: Self

pub const DARKER_HAN: Self

pub const DARKER_VIOLET: Self

pub const DARKER_PURPLE: Self

pub const DARKER_FUCHSIA: Self

pub const DARKER_MAGENTA: Self

pub const DARKER_PINK: Self

pub const DARKER_CRIMSON: Self

pub const DARKEST_RED: Self

pub const DARKEST_FLAME: Self

pub const DARKEST_ORANGE: Self

pub const DARKEST_AMBER: Self

pub const DARKEST_YELLOW: Self

pub const DARKEST_LIME: Self

pub const DARKEST_CHARTREUSE: Self

pub const DARKEST_GREEN: Self

pub const DARKEST_SEA: Self

pub const DARKEST_TURQUOISE: Self

pub const DARKEST_CYAN: Self

pub const DARKEST_SKY: Self

pub const DARKEST_AZURE: Self

pub const DARKEST_BLUE: Self

pub const DARKEST_HAN: Self

pub const DARKEST_VIOLET: Self

pub const DARKEST_PURPLE: Self

pub const DARKEST_FUCHSIA: Self

pub const DARKEST_MAGENTA: Self

pub const DARKEST_PINK: Self

pub const DARKEST_CRIMSON: Self

pub const BRASS: Self

pub const COPPER: Self

pub const GOLD: Self

pub const SILVER: Self

pub const CELADON: Self

pub const PEACH: Self