pub struct NeighborCell {
pub relative_position: Position,
pub weight: f32,
}Expand description
Represents a neighbor cell in the kernel transformation method.
Fields
relative_position: PositionWhich map cell this transform takes its value from, relative to the current cell. That is to say, if the transform is currently working on cell (5, 2) and this field is (-1, 1), it will get its value from (4, 3).
weight: f32What to scale this neighbor cell’s value by when calculating the new value of the current cell.